package com.akamai.androidmdt.androidsdkdemo;


import android.os.Bundle;
import android.support.v4.app.FragmentActivity;
import android.util.Log;
import android.widget.ProgressBar;

import com.akamai.ads.AdsHelper;
import com.akamai.ads.IAdsComponentListener;
import com.akamai.ima.AdsComponent;
import com.akamai.media.IPlayerEventsListener;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerContainer.VideoPlayerContainerCallback;
import com.akamai.media.VideoPlayerView;
import com.akamai.media.elements.MediaResource;
import com.akamai.uimobile.media.MediaPlayerController;


public class PlayerActivity extends FragmentActivity
        implements IPlayerEventsListener, IAdsComponentListener,VideoPlayerContainerCallback {

    private static final String TAG = PlayerActivity.class.getName();
    private String AMP_LICENSE = "t_SEBeOhcpLarm8Vs5q2e_nbDUifOB8qEv7AdZVbaO03BOOhR9GoI7SrbV7_kXpZVuw3It4VRpPq0iYgkFR40w==";

    private String ADS_URL = "http://pubads.g.doubleclick.net/gampad/ads?sz=640x480&iu=/124319096/external/ad_rule_samples&ciu_szs=300x250&ad_rule=1&impl=s&gdfp_req=1&env=vp&output=vmap&unviewed_position_start=1&cust_params=deployment%3Ddevsite%26sample_ar%3Dpremidpost&cmsid=496&vid=short_onecue&correlator=";

    private VideoPlayerContainer mVideoContainer;
    private VideoPlayerView mVideoView;
    private ProgressBar progressBar;
    private AdsComponent adsComponent;
    private MediaPlayerController mediaController;
    private MediaResource mediaResource;

    private Boolean mWasPlaying = false;
    private Boolean isAdsPlaying = false;
    private int mCurrentPosition = 0;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_player);

        progressBar = (ProgressBar) findViewById(R.id.progressBar);
        mediaController = (MediaPlayerController) findViewById(R.id.mediaController);
        mediaController.hideFullscreenButton();

        mVideoContainer = (VideoPlayerContainer) findViewById(R.id.view);
        mVideoContainer.addVideoPlayerContainerCallback(this);
        mVideoContainer.prepareResource(getString(R.string.stream_url));
        adsComponent = new AdsComponent(PlayerActivity.this);
    }

    @Override
    public void onVideoPlayerCreated() {
        Log.i(TAG,"onVideoPlayerCreated");
    }

    @Override
    public void onResourceReady(MediaResource resource) {
        Log.i(TAG,"onResourceReady " + resource.getRedirectedUrl());
        mediaResource = resource;
        configVideoView();
        configAdsComponent();
        mVideoView.play(mediaResource);
    }

    @Override
    public void onResourceError() {
        Log.e(TAG, "onResourceError");
    }

    private void configVideoView() {
        mVideoView = mVideoContainer.getVideoPlayer();
        mediaController.setVideoPlayerView(mVideoContainer);
        mVideoView.setProgressBarControl(progressBar);
        mVideoView.addEventsListener(this);
        mVideoView.setLicense(AMP_LICENSE);
        mVideoView.setKeepScreenOn(true);
        mVideoView.setProgressBarControl(progressBar);
    }

    private void configAdsComponent() {
        adsComponent.setVideoPlayerView(mVideoView);
        adsComponent.attachToVideoPlayerContainer(mVideoContainer);
        adsComponent.addEventsListener(this);
        adsComponent.setAdsUrl(ADS_URL);
    }

    @Override
    public void onPause() {
        if(adsComponent!=null) adsComponent.pauseAd();
        if ((mVideoView != null) && (mVideoView.isPlaying()) && !isAdsPlaying) {
            mCurrentPosition = mVideoView.getTimePosition();
            mVideoView.stop();
            mWasPlaying = true;
        }
        super.onPause();
    }

    @Override
    public void onResume() {
        if(adsComponent!=null) adsComponent.resumeAd();
        if (mWasPlaying && !isAdsPlaying) {
            mVideoView.play(mediaResource, mCurrentPosition);
            mWasPlaying = false;
        }
        super.onResume();
    }

    @Override
    public void onDestroy(){
        super.onDestroy();
        adsComponent.onDestroy();
        mVideoView.onDestroy();
        mVideoView = null;
    }


    @Override
    public boolean onPlayerEvent(int eventType) {
        return true;
    }


    @Override
    public boolean onPlayerExtendedEvent(int i, int i2, int i3) {
        return true;
    }


    //code for add event listener function
    @Override
    public void onAdsError(String s) {
        Log.e(TAG,"onAdsError "+s);
    }

    @Override
    public void onPauseContentRequested() {
        isAdsPlaying = true;
        mediaController.showControlBar(false);
        Log.i(TAG,"onPauseContentRequested");
    }

    @Override
    public void onResumeContentRequested() {
        isAdsPlaying = false;
        mediaController.showControlBar(true);
        Log.i(TAG,"onResumeContentRequested");
    }

    @Override
    public void onAdsLoaded() {
        Log.i(TAG,"onAdsLoaded");
    }

    @Override
    public void onAdsStarted() {
        Log.i(TAG,"onAdsStarted");
    }

    @Override
    public void onAdsPaused() {
        Log.i(TAG,"onAdsPaused");
    }

    @Override
    public void onAdsResumed() {
        Log.i(TAG,"onAdsResumed");
    }

    @Override
    public void onAdsEnded() {
        onAdsTrackProgress(IAdsComponentListener.ADS_PROGRESS_COMPLETED);
    }

    @Override
    public void onAdsTrackProgress(int i) {
        Log.i(TAG, "onAdsTrackProgress " + AdsHelper.translateProgressCode(i) + "%");
    }

    @Override
    public void onAdsPlayheadUpdate(int i) {
        Log.i(TAG, "onAdsPlayheadUpdate " + i);
    }

}
