package com.akamai.ampdemo;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.View;
import android.widget.Button;
import android.widget.ProgressBar;

import com.akamai.ads.IAdsComponentListener;
import com.akamai.analytics.nielsenanalytics.NielsenDcrAnalyticsTracker;
import com.akamai.config.AMPConfigLoader;
import com.akamai.config.data.NielsenAdData;
import com.akamai.config.data.NielsenAppData;
import com.akamai.config.data.NielsenContentData;
import com.akamai.config.data.NielsenData;
import com.akamai.ima.AdsComponent;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;
import com.akamai.media.elements.AMPLibraryInfo;
import com.akamai.media.elements.MediaResource;
import com.akamai.uimobile.media.MediaPlayerController;
import com.nielsen.app.sdk.AppSdk;

import java.util.HashMap;
import java.util.Map;


public class PlayerActivity extends Activity
        implements VideoPlayerContainer.VideoPlayerContainerCallback,IAdsComponentListener {

    private static final String TAG = PlayerActivity.class.getSimpleName();
    private static final String ANDROID_SDK_LICENSE = "duFlD_z1uYSAsd80HVwysOeY-OaKTMZpQriNZsSC05QCRZVuu66gt4eNBcZiVSvW0DVjNh14CvwtonAkEMHDTA==";

    private static final String NIELSEN_DATA_APP_ID = "T9C30276D-DB8E-42D6-9768-893BD504623D";
    private static final String NIELSEN_DATA_APP_VERSION = AMPLibraryInfo.VERSION;
    private static final String NIELSEN_DATA_APP_NAME = "Akamai";
    private static final String NIELSEN_DATA_SF_CODE = "cert";

    private VideoPlayerContainer videoPlayerContainer;
    private VideoPlayerView videoPlayerView;
    private ProgressBar progressBar;
    private MediaPlayerController mediaPlayerController;
    private AMPConfigLoader ampConfigLoader;

    private AdsComponent adsComponent;
    private NielsenDcrAnalyticsTracker nielsenAnalytics;

    private MediaResource resource;
    private Video videoSelected;
    private boolean mWasPlaying;
    private boolean isAdsPlaying = false;

    private Button buttonOptOut;
    private String optOutPage = null;
    private String optOutRequest = "";


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_player);

        Intent intent = getIntent();
        videoSelected = (Video) intent.getSerializableExtra("videoSelected");

        progressBar = (ProgressBar) findViewById(R.id.progressBar);
        videoPlayerContainer = (VideoPlayerContainer) findViewById(R.id.playerViewCtrl);
        mediaPlayerController = (MediaPlayerController) findViewById(R.id.playerControls);
        mediaPlayerController.hideFullscreenButton();
        videoPlayerContainer.addVideoPlayerContainerCallback(this);
        videoPlayerContainer.prepareResource(videoSelected.videoURL);

        buttonOptOut = (Button) findViewById(R.id.btnOptOut);
        if (buttonOptOut != null) {
            buttonOptOut.setOnClickListener(onOptOutClick());
        }
    }

    public void initAnalyticsTracker() {
        /*
        *  There are two options for initializing the Analytics Tracker:
        *  1) Using a config file, like http://projects.mediadev.edgesuite.net/customers/akamai/android/demos/nielsendcr.json
        *     via the empty constructor: new NielsenDcrAnalyticsTracker();
        *  2) Sending that info through Java objects and Java maps,
        *     via the constructor with a parameter: new NielsenDcrAnalyticsTracker(buildNielsenData())
        */

        //nielsenAnalytics = new NielsenDcrAnalyticsTracker();

        nielsenAnalytics = new NielsenDcrAnalyticsTracker(buildNielsenData());
        nielsenAnalytics.setVideoPlayerView(videoPlayerView);
        nielsenAnalytics.enableReporting(true);
        nielsenAnalytics.init(PlayerActivity.this);

        Log.i("AMP+NielsenDCR", "AMP v" + AMPLibraryInfo.VERSION + " Nielsen DCR " + nielsenAnalytics.getAppSdkVersion());
    }

    private NielsenData buildNielsenData() {
        NielsenAppData appData = buildAppData();
        NielsenContentData contentData = buildContentData();
        NielsenAdData adData = buildAdData();
        NielsenData data = new NielsenData(appData, contentData, adData);
        return data;
    }

    private NielsenAppData buildAppData() {
        Map<String, String> data = new HashMap<>();
        data.put("appid", NIELSEN_DATA_APP_ID);
        data.put("appversion", NIELSEN_DATA_APP_VERSION);
        data.put("appname", NIELSEN_DATA_APP_NAME);
        data.put("sfcode", NIELSEN_DATA_SF_CODE);

        NielsenAppData appData = new NielsenAppData(data);
        return appData;
    }

    private NielsenContentData buildContentData() {
        Map<String, String> data = new HashMap<>();
        data.put("clientid", "Nielsen");
        data.put("Nielsen", "Nielsen");
        data.put("type", "content");
        data.put("program", "MySampleProgram");
        data.put("title", "MySampleTitle");
        data.put("assetid", "MySampleAssetId");
        data.put("isfullepisode", "Y");
        data.put("segB", "MySampleSegB");
        data.put("airdate", "20161013 20:00:00");

        NielsenContentData contentData = new NielsenContentData(data);
        return contentData;
    }

    private NielsenAdData buildAdData() {
        Map<String, String> data = new HashMap<>();
        data.put("type", "preroll");
        data.put("assetid_ad", "myAdAssetId");
        data.put("hasAds", "1");

        NielsenAdData appData = new NielsenAdData(data);
        return appData;
    }

    private void initGoogleAds() {
        adsComponent = new AdsComponent(PlayerActivity.this);
        adsComponent.setVideoPlayerView(videoPlayerView);
        adsComponent.attachToVideoPlayerContainer(videoPlayerContainer);
        adsComponent.setAdsUrl(videoSelected.adsUrl);

        // IMPORTANT: Nielsen should listen events from Google Ads
        adsComponent.addEventsListener(nielsenAnalytics);
        adsComponent.addEventsListener(this);
    }

    private View.OnClickListener onOptOutClick() {
        return new View.OnClickListener() {
            public void onClick(View v) {
                if (nielsenAnalytics==null) return;

                optOutPage = nielsenAnalytics.getOptOutUrl();

                if ((optOutPage == null) || (optOutPage.isEmpty())) {
                    onNoOptOutUrl();
                } else {
                    onOptOutUrl();
                }
            }
        };
    }

    private void onOptOutUrl() {
        Intent i = new Intent(PlayerActivity.this, OptOutActivity.class);
        final Bundle pars = new Bundle();
        if (i != null && pars != null) {
            pars.putString(Global.keyWebUrl, optOutPage);
            i.putExtras(pars);
            PlayerActivity.this.startActivityForResult(i, Global.OPTOUT_REQUEST);
        }
    }

    private void onNoOptOutUrl() {
        final AlertDialog.Builder builder = new AlertDialog.Builder(PlayerActivity.this);
        builder.setMessage("No Opt-Out Url is available.").setTitle("Launch Opt-Out page").setCancelable(false)
                .setPositiveButton("Ok", new DialogInterface.OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialog, int which) {
                        dialog.cancel();
                    }
                });
        builder.show();
    }

    @Override
    public void onVideoPlayerCreated() {
        Log.i(TAG, "onVideoPlayerCreated()");
    }

    @Override
    public void onResourceError() {
        Log.e(TAG, "onResourceError()");
    }

    @Override
    public void onResourceReady(MediaResource mediaResource) {
        resource = mediaResource;
        videoPlayerView = videoPlayerContainer.getVideoPlayer();
        videoPlayerView.setLicense(ANDROID_SDK_LICENSE);
        videoPlayerView.setLogEnabled(true);
        videoPlayerView.setKeepScreenOn(true);
        mediaPlayerController.setVideoPlayerView(videoPlayerContainer);
        videoPlayerView.setProgressBarControl(progressBar);
        ampConfigLoader = new AMPConfigLoader(getConfigLoaderListener());
        ampConfigLoader.loadConfig(videoSelected.nielsenConfigURL);

        Log.i(TAG, "AMP v: " + AMPLibraryInfo.VERSION + " with Nielsen DCR v" + AppSdk.getMeterVersion());
    }

    // The NIELSEN_CONFIG_URL is processed and loaded into an AMPConfig object,
    // both Nielsen Analytics and Google Ads are initialized,
    // now we can start playing the video (represented by the MediaResource object)
    private AMPConfigLoader.ConfigLoaderListener getConfigLoaderListener() {
        return new AMPConfigLoader.ConfigLoaderListener() {
            @Override
            public void configLoaded() {
                if (videoSelected.nielsenConfigURL != null)
                    initAnalyticsTracker();
                if (videoSelected.adsUrl != null)
                    initGoogleAds();

                videoPlayerView.play(resource);
            }
        };
    }

    @Override
    protected void onResume() {
        Log.i(TAG, "onResume");
        if (adsComponent != null) adsComponent.resumeAd();
        if (videoPlayerView != null && mWasPlaying && !isAdsPlaying)
            videoPlayerView.resume();

        super.onResume();
    }

    @Override
    protected void onPause() {
        Log.i(TAG, "onPause");
        if (adsComponent != null) adsComponent.pauseAd();
        if ((videoPlayerView != null) && (videoPlayerView.isPlaying()) && !isAdsPlaying) {
            videoPlayerView.pause();
            mWasPlaying = true;
        }
        super.onPause();
    }

    @Override
    protected void onDestroy() {
        Log.i(TAG, "onDestroy()");
        nielsenAnalytics.destroy();

        if (videoPlayerView != null) {
            videoPlayerView.onDestroy();
        }
        super.onDestroy();
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        return false;
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);

        if ((requestCode == Global.OPTOUT_REQUEST) && (data != null)) {
            String result = data.getStringExtra(Global.keyOptResult);
            if (result != null) {
                if (result.indexOf("nielsenappsdk") == 0) {
                    optOutRequest = result; // result.substring(result.length()-1);
                    Log.d(TAG, "OPT-OUT " + optOutRequest);
                } else if (result.equals("closeAll")) {
                    Log.d(TAG, "close " + result);
                }

                nielsenAnalytics.userOptOut(result);
            }
        }
    }

    @Override
    public void onAdsError(String s) {
        Log.e(TAG,"onAdsError "+s);
    }

    @Override
    public void onPauseContentRequested() {
        mediaPlayerController.showControlBar(false);
    }

    @Override
    public void onResumeContentRequested() {
        mediaPlayerController.showControlBar(true);
        Log.e(TAG,"onResumeContentRequested");
    }

    @Override
    public void onAdsLoaded() {
        Log.e(TAG,"onAdsLoaded");
    }

    @Override
    public void onAdsStarted() {
        Log.e(TAG,"onAdsStarted");
    }

    @Override
    public void onAdsPaused() {
        Log.e(TAG,"onAdsPaused");
    }

    @Override
    public void onAdsResumed() {
        Log.e(TAG,"onAdsResumed");
    }

    @Override
    public void onAdsEnded() {
        Log.e(TAG,"onAdsEnded");
    }

    @Override
    public void onAdsTrackProgress(int i) {
        Log.e(TAG,"onAdsTrackProgress "+i);
    }

    @Override
    public void onAdsPlayheadUpdate(int i) {
        Log.e(TAG,"onAdsPlayheadUpdate "+i);
    }
}
