package tv.freewheel.ad.interfaces;

/**
 *	Interface for creative rendition asset, only for renderer use by now
 */
public interface ICreativeRenditionAsset {
	/**
	 *	Get the URL of the asset
	 *	
	 *	Returns:
	 *		URL in a string
	 */
	public String getURL();

	/**
	 *	Change the URL of the asset
	 *	
	 *	Parameters:
	 *		URL		-	URL of the asset
	 *	
	 *	Usage:
	 *		This method is for player and translator development only
	 */
	public void setURL(String url);

	/**
	 *	Returns the content of the asset
	 *	
	 *	Returns:
	 *		Content in a string
	 */
	public String getContent();

	/**
	 *	Set the content of the asset
	 *	
	 *	Parameters:
	 *		Content in a string
	 *	
	 *	Usage:
	 *		This method is for translator development only
	 */
	public void setContent(String content);

	/**
	 *	Mime type of the asset
	 *	
	 *	Returns:
	 *		Mime type in string
	 */
	public String getMimeType();

	/**
	 *	Set the mime type of the rendition
	 *	
	 *	Parameters:
	 *		Mime type in a string
	 *	
	 *	Usage:
	 *		This method is for translator development only
	 */
	public void setMimeType(String mimeType);

	/**
	 *	Content type of the asset
	 *	
	 *	Returns:
	 *		Content type in string
	 */
	public String getContentType();

	/**
	 *	Set the content type of the rendition
	 *	
	 *	Parameters:
	 *		Content type in a string
	 *	
	 *	Usage:
	 *		This method is for translator development only
	 */
	public void setContentType(String contentType);

	/**
	 *	Get size of the asset
	 *	
	 *	Returns:
	 *		size in bytes, or -1 if unknown.
	 */
	public int getBytes();

	/**
	 *	Set size of the asset
	 *	
	 *	Parameters:
	 *		size in bytes, or -1 if unknown.
	 *	
	 *	Usage:
	 *		This method is for translator development only
	 */
	public void setBytes(int bytes);
}
